summaryrefslogtreecommitdiffstats
path: root/libk9copy/k9dvdtitle.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /libk9copy/k9dvdtitle.h
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk9copy/k9dvdtitle.h')
-rw-r--r--libk9copy/k9dvdtitle.h128
1 files changed, 66 insertions, 62 deletions
diff --git a/libk9copy/k9dvdtitle.h b/libk9copy/k9dvdtitle.h
index 9b29f53..4e74ddc 100644
--- a/libk9copy/k9dvdtitle.h
+++ b/libk9copy/k9dvdtitle.h
@@ -23,41 +23,43 @@
#include "k9common.h"
#include "k9dvd.h"
#include "k9dvdchapter.h"
-#include <qdatetime.h>
-#include <qstringlist.h>
-#include <qptrlist.h>
+#include <tqdatetime.h>
+#include <tqstringlist.h>
+#include <tqptrlist.h>
class k9DVDTitleSet;
-class k9DVDVideoStream : public QObject{
+class k9DVDVideoStream : public TQObject{
Q_OBJECT
+TQ_OBJECT
friend class k9DVDTitle;
private: // Private attributes
public: // Public methods
};
-class k9DVDAudioStream : public QObject{
+class k9DVDAudioStream : public TQObject{
Q_OBJECT
+TQ_OBJECT
friend class k9DVDTitle;
friend class k9DVD;
private: // Private attributes
/** */
- QString langCod;
+ TQString langCod;
/** */
- QString language;
+ TQString language;
/** */
- QString format;
+ TQString format;
/** */
- QString frequency;
+ TQString frequency;
/** */
- QString quantization;
+ TQString quantization;
/** */
int channels;
/** */
int appMode;
/** */
- QString content;
+ TQString content;
/** */
float size_mb;
/** */
@@ -67,22 +69,22 @@ private: // Private attributes
int m_streamId;
public: // Public methods
k9DVDAudioStream();
- /** Read property of QString langCod. */
- virtual const QString& getlangCod();
- /** Read property of QString language. */
- virtual const QString& getlanguage();
- /** Read property of QString format. */
- virtual const QString& getformat();
- /** Read property of QString frequency. */
- virtual const QString& getfrequency();
- /** Read property of QString quantization. */
- virtual const QString& getquantization();
+ /** Read property of TQString langCod. */
+ virtual const TQString& getlangCod();
+ /** Read property of TQString language. */
+ virtual const TQString& getlanguage();
+ /** Read property of TQString format. */
+ virtual const TQString& getformat();
+ /** Read property of TQString frequency. */
+ virtual const TQString& getfrequency();
+ /** Read property of TQString quantization. */
+ virtual const TQString& getquantization();
/** Read property of int channels. */
virtual const int& getchannels();
/** Read property of int appMode. */
virtual const int& getappMode();
- /** Read property of QString content. */
- virtual const QString& getcontent();
+ /** Read property of TQString content. */
+ virtual const TQString& getcontent();
/** Read property of float size_mb. */
virtual const float& getsize_mb();
/** Write property of bool selected. */
@@ -97,35 +99,36 @@ public: // Public methods
};
-class k9DVDSubtitle : public QObject{
+class k9DVDSubtitle : public TQObject{
Q_OBJECT
+TQ_OBJECT
friend class k9DVDTitle;
friend class k9DVD;
private: // Private attributes
/** */
- QString langCod;
+ TQString langCod;
/** */
- QString language;
+ TQString language;
/** */
int num;
/** */
- QString content;
+ TQString content;
/** */
float size_mb;
/** */
bool selected;
- QValueList<int> id;
+ TQValueList<int> id;
k9DVDTitle *title;
public: // Public methods
k9DVDSubtitle();
- /** Read property of QString langCod. */
- virtual const QString& getlangCod();
- /** Read property of QString language. */
- virtual const QString& getlanguage();
+ /** Read property of TQString langCod. */
+ virtual const TQString& getlangCod();
+ /** Read property of TQString language. */
+ virtual const TQString& getlanguage();
/** Read property of int num. */
virtual const int& getnum();
- /** Read property of QString content. */
- virtual const QString& getcontent();
+ /** Read property of TQString content. */
+ virtual const TQString& getcontent();
/** Read property of float size_mb. */
virtual const float& getsize_mb();
/** Write property of bool selected. */
@@ -133,15 +136,16 @@ public: // Public methods
/** Read property of bool selected. */
virtual const bool& getselected();
virtual k9DVDTitle* gettitle();
- virtual QValueList<int>& getID();
+ virtual TQValueList<int>& getID();
};
class k9TitleEncOpt;
-class k9DVDTitle : public QObject{
-Q_OBJECT
+class k9DVDTitle : public TQObject{
+Q_OBJECT
+TQ_OBJECT
friend class k9DVD;
private: // Public attributes
unsigned int ts_nr;
@@ -149,25 +153,25 @@ private: // Public attributes
int streamCount;
int audioStreamCount;
int subPictureCount;
- QTime length;
+ TQTime length;
k9DVDVideoStream videoStream;
- QObjectList audioStreams;
- QObjectList subtitles;
+ TQObjectList audioStreams;
+ TQObjectList subtitles;
int VTS;
int TTN;
float FPS;
- QString format;
- QString aspectRatio;
+ TQString format;
+ TQString aspectRatio;
int numTitle;
- QString width;
- QString height;
- QStringList palette;
- QString DF;
+ TQString width;
+ TQString height;
+ TQStringList palette;
+ TQString DF;
float size_mb;
int angleCount;
float videosize_mb;
float vobusize_mb;
- QString name;
+ TQString name;
k9DVDTitle* nextTitle;
int id;
k9DVDTitleset *m_titleset;
@@ -175,7 +179,7 @@ private: // Public attributes
k9DVDSubtitle *m_defSubtitle;
bool m_defAudioSet;
bool m_defSubtitleSet;
- QPtrList <k9DVDTitle> m_titles;
+ TQPtrList <k9DVDTitle> m_titles;
uint32_t m_sectors;
bool m_forceFactor;
float m_factor;
@@ -187,19 +191,19 @@ public: // Public methods
virtual const int& getstreamCount();
virtual const int& getaudioStreamCount();
virtual const int& getsubPictureCount();
- virtual const QTime& getlength();
- virtual QTime gettotallength();
- virtual QTime getSelectedLength();
+ virtual const TQTime& getlength();
+ virtual TQTime gettotallength();
+ virtual TQTime getSelectedLength();
virtual const int& getVTS();
virtual const int& getTTN();
virtual const float& getFPS();
- virtual const QString& getformat();
- virtual const QString& getaspectRatio();
- virtual const QString& getwidth();
- virtual const QString& getheight();
- virtual void getpalette(int i,QString & c);
- virtual const QString& getDF();
+ virtual const TQString& getformat();
+ virtual const TQString& getaspectRatio();
+ virtual const TQString& getwidth();
+ virtual const TQString& getheight();
+ virtual void getpalette(int i,TQString & c);
+ virtual const TQString& getDF();
virtual const int& getangleCount();
virtual const int& getnumTitle();
virtual k9DVDAudioStream *getaudioStream(int num);
@@ -211,8 +215,8 @@ public: // Public methods
virtual const uint64_t getChaptersSize(bool _selected);
virtual const float& getvideosize_mb();
virtual bool isSelected();
- virtual void setname( const QString& _newVal);
- virtual const QString& getname();
+ virtual void setname( const TQString& _newVal);
+ virtual const TQString& getname();
virtual int getpgc();
virtual void setnextTitle(k9DVDTitle * nTitle);
virtual k9DVDTitle* getnextTitle();
@@ -226,12 +230,12 @@ public: // Public methods
virtual k9DVDSubtitle* getDefSubtitle() const;
virtual bool getDefAudioSet() const {return m_defAudioSet;};
virtual bool getDefSubtitleSet() const {return m_defSubtitleSet;};
- virtual QPtrList< k9DVDTitle > getTitles() const {return m_titles;};
+ virtual TQPtrList< k9DVDTitle > getTitles() const {return m_titles;};
virtual uint32_t getsectors() { return m_sectors;};
virtual float getfactor() { return m_factor;};
virtual bool getforceFactor() { return m_forceFactor;};
virtual void selectChapters(bool _state);
- virtual QPtrList< k9DVDChapter > getChapters() const {return chapters;};
+ virtual TQPtrList< k9DVDChapter > getChapters() const {return chapters;};
virtual k9TitleEncOpt* getEncOpt() ;
public slots:
@@ -244,7 +248,7 @@ private: // Private methods
k9DVDAudioStream* addAudioStream();
k9DVDChapter* addChapter(int num);
k9DVDSubtitle* addSubtitle(int num);
- QPtrList <k9DVDChapter> chapters;
+ TQPtrList <k9DVDChapter> chapters;
bool indexed;
bool forceSelection;
int pgc;